[PATCH 3/4] Set sensitivity for the preview button (KeyboardSpoke) when something is selected

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



---
 pyanaconda/ui/gui/spokes/keyboard.py |    6 +++++-
 pyanaconda/ui/gui/spokes/keyboard.ui |    2 +-
 2 files changed, 6 insertions(+), 2 deletions(-)

diff --git a/pyanaconda/ui/gui/spokes/keyboard.ui b/pyanaconda/ui/gui/spokes/keyboard.ui
index de1c1f6..c471287 100644
--- a/pyanaconda/ui/gui/spokes/keyboard.ui
+++ b/pyanaconda/ui/gui/spokes/keyboard.ui
@@ -343,7 +343,7 @@ any layout to the top of the list to select it as the default.</property>
                               </packing>
                             </child>
                             <child>
-                              <object class="GtkButton" id="settingsButton">
+                              <object class="GtkButton" id="previewButton">
                                 <property name="visible">True</property>
                                 <property name="can_focus">True</property>
                                 <property name="receives_default">True</property>
diff --git a/pyanaconda/ui/gui/spokes/keyboard.py b/pyanaconda/ui/gui/spokes/keyboard.py
index 9852b8f..4b55367 100644
--- a/pyanaconda/ui/gui/spokes/keyboard.py
+++ b/pyanaconda/ui/gui/spokes/keyboard.py
@@ -134,11 +134,13 @@ class KeyboardSpoke(NormalSpoke):
         self._upButton = self.builder.get_object("upButton")
         self._downButton = self.builder.get_object("downButton")
         self._removeButton = self.builder.get_object("removeLayoutButton")
+        self._previewButton = self.builder.get_object("previewButton")
 
         # Start with no buttons enabled, since nothing is selected.
         self._upButton.set_sensitive(False)
         self._downButton.set_sensitive(False)
         self._removeButton.set_sensitive(False)
+        self._previewButton.set_sensitive(False)
 
     def _addLayout(self, store, name):
         store.append([name])
@@ -208,12 +210,14 @@ class KeyboardSpoke(NormalSpoke):
             self._upButton.set_sensitive(False)
             self._downButton.set_sensitive(False)
             self._removeButton.set_sensitive(False)
+            self._previewButton.set_sensitive(False)
             return
 
         (store, selected) = selection.get_selected_rows()
 
         # If something's selected, always enable the remove button.
         self._removeButton.set_sensitive(True)
+        self._previewButton.set_sensitive(True)
 
         # Disable the Up button if the top row's selected, and disable the
         # Down button if the bottom row's selected.
@@ -208,12 +210,14 @@ class KeyboardSpoke(NormalSpoke):
         (store, selected) = selection.get_selected_rows()
 
-        # If something's selected, always enable the remove button.
+        # If something's selected, always enable the remove and preview buttons.
         self._removeButton.set_sensitive(True)
-- 
1.7.4.4

_______________________________________________
Anaconda-devel-list mailing list
Anaconda-devel-list@xxxxxxxxxx
https://www.redhat.com/mailman/listinfo/anaconda-devel-list


[Index of Archives]     [Kickstart]     [Fedora Users]     [Fedora Legacy List]     [Fedora Maintainers]     [Fedora Desktop]     [Fedora SELinux]     [Big List of Linux Books]     [Yosemite News]     [Yosemite Photos]     [KDE Users]     [Fedora Tools]
  Powered by Linux